aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorzsloan2018-12-05 11:48:24 -0600
committerzsloan2018-12-05 11:48:24 -0600
commit4fbeea6d1ed1ac2b81eb431ee837201945abc841 (patch)
treec329e8929f1ab1856555787f6909c8eb47483ca7
parentdc3bc97b2ae2e751f68ad63359734d569895c711 (diff)
downloadgenenetwork2-4fbeea6d1ed1ac2b81eb431ee837201945abc841.tar.gz
Fixed issue where SNP track for mapping did not appear correctly
Updated style for a variety of tables Moved transform/blocking tools for trait sample table into its own tab Added some new customization options to network graph Started work on implementing third party link-outs Updated drop-down generation script to order datasets according to CreateTime
-rw-r--r--wqflask/maintenance/gen_select_dataset.py2
-rw-r--r--wqflask/wqflask/external_tools/send_to_bnw.py0
-rw-r--r--wqflask/wqflask/heatmap/heatmap.py2
-rw-r--r--wqflask/wqflask/marker_regression/display_mapping_results.py3
-rw-r--r--wqflask/wqflask/marker_regression/run_mapping.py6
-rw-r--r--wqflask/wqflask/static/new/css/marker_regression.css36
-rw-r--r--wqflask/wqflask/static/new/css/show_trait.css2
-rw-r--r--wqflask/wqflask/static/new/javascript/dataset_menu_structure.json224
-rw-r--r--wqflask/wqflask/static/new/javascript/network_graph.js125
-rw-r--r--wqflask/wqflask/templates/collections/list.html8
-rw-r--r--wqflask/wqflask/templates/collections/view.html36
-rw-r--r--wqflask/wqflask/templates/gsearch_gene.html13
-rw-r--r--wqflask/wqflask/templates/gsearch_pheno.html23
-rw-r--r--wqflask/wqflask/templates/mapping_results.html41
-rw-r--r--wqflask/wqflask/templates/network_graph.html48
-rw-r--r--wqflask/wqflask/templates/search_result_page.html43
-rw-r--r--wqflask/wqflask/templates/show_trait_edit_data.html6
-rw-r--r--wqflask/wqflask/templates/show_trait_transform_and_filter.html2
18 files changed, 368 insertions, 252 deletions
diff --git a/wqflask/maintenance/gen_select_dataset.py b/wqflask/maintenance/gen_select_dataset.py
index 55c642a4..4ad921a2 100644
--- a/wqflask/maintenance/gen_select_dataset.py
+++ b/wqflask/maintenance/gen_select_dataset.py
@@ -248,7 +248,7 @@ def build_datasets(species, group, type_name):
ProbeSetFreeze.ProbeFreezeId = ProbeFreeze.Id and Tissue.Name = '%s' and
ProbeFreeze.TissueId = Tissue.Id and ProbeFreeze.InbredSetId = InbredSet.Id and
ProbeSetFreeze.confidentiality < 1 and ProbeSetFreeze.public > 0 order by
- ProbeSetFreeze.OrderList asc""" % (species, group, type_name))
+ ProbeSetFreeze.CreateTime desc""" % (species, group, type_name))
dataset_results = Cursor.fetchall()
datasets = []
diff --git a/wqflask/wqflask/external_tools/send_to_bnw.py b/wqflask/wqflask/external_tools/send_to_bnw.py
new file mode 100644
index 00000000..e69de29b
--- /dev/null
+++ b/wqflask/wqflask/external_tools/send_to_bnw.py
diff --git a/wqflask/wqflask/heatmap/heatmap.py b/wqflask/wqflask/heatmap/heatmap.py
index af75d441..7b328cb5 100644
--- a/wqflask/wqflask/heatmap/heatmap.py
+++ b/wqflask/wqflask/heatmap/heatmap.py
@@ -46,9 +46,7 @@ from flask import Flask, g
class Heatmap(object):
def __init__(self, start_vars, temp_uuid):
-
trait_db_list = [trait.strip() for trait in start_vars['trait_list'].split(',')]
-
helper_functions.get_trait_db_obs(self, trait_db_list)
self.temp_uuid = temp_uuid
diff --git a/wqflask/wqflask/marker_regression/display_mapping_results.py b/wqflask/wqflask/marker_regression/display_mapping_results.py
index 09646f57..e63e4af2 100644
--- a/wqflask/wqflask/marker_regression/display_mapping_results.py
+++ b/wqflask/wqflask/marker_regression/display_mapping_results.py
@@ -772,7 +772,8 @@ class DisplayMappingResults(object):
fontZoom = 1.5
drawSNPLocationY = yTopOffset + plotHeight
- chrName = self.genotype[0].name
+ #chrName = self.genotype[0].name
+ chrName = self.ChrList[self.selectedChr][0]
stepMb = (endMb-startMb)/plotWidth
strainId1, strainId2 = self.diffCol
diff --git a/wqflask/wqflask/static/new/css/marker_regression.css b/wqflask/wqflask/static/new/css/marker_regression.css
index d81b5021..8d205143 100644
--- a/wqflask/wqflask/static/new/css/marker_regression.css
+++ b/wqflask/wqflask/static/new/css/marker_regression.css
@@ -35,4 +35,38 @@ rect.pane {
/*rect {
stroke: WhiteSmoke;
fill: Azure;
-}*/ \ No newline at end of file
+}*/
+
+tr .outlier {
+ background-color: #ffff99;
+}
+
+table.dataTable thead th{
+ border-right: 1px solid white;
+ color: white;
+ background-color: #369;
+}
+
+table.dataTable thead .sorting_asc {
+ background-image: url("../packages/DataTables/images/sort_asc_disabled.png");
+}
+table.dataTable thead .sorting_desc {
+ background-image: url("../packages/DataTables/images/sort_desc_disabled.png");
+}
+
+table.dataTable thead th {
+ padding: 4px 18px 4px 10px;
+}
+
+table.dataTable tbody td {
+ padding: 3px 20px 1px 10px;
+}
+
+table.dataTable.cell-border tbody th, table.dataTable.cell-border tbody td {
+ border-top: 1px solid #ccc;
+ border-right: 1px solid #ccc;
+}
+table.dataTable.cell-border tbody tr th:first-child,
+table.dataTable.cell-border tbody tr td:first-child {
+ border-left: 1px solid #ccc;
+} \ No newline at end of file
diff --git a/wqflask/wqflask/static/new/css/show_trait.css b/wqflask/wqflask/static/new/css/show_trait.css
index c03b6103..59901404 100644
--- a/wqflask/wqflask/static/new/css/show_trait.css
+++ b/wqflask/wqflask/static/new/css/show_trait.css
@@ -32,7 +32,7 @@ table.dataTable thead th {
}
table.dataTable tbody td {
- padding: 3px 20px 1px 10px;
+ padding: 4px 20px 2px 10px;
}
table.dataTable.cell-border tbody th, table.dataTable.cell-border tbody td {
diff --git a/wqflask/wqflask/static/new/javascript/dataset_menu_structure.json b/wqflask/wqflask/static/new/javascript/dataset_menu_structure.json
index 72008225..a4ec6ece 100644
--- a/wqflask/wqflask/static/new/javascript/dataset_menu_structure.json
+++ b/wqflask/wqflask/static/new/javascript/dataset_menu_structure.json
@@ -1347,14 +1347,14 @@
"GSE9588 Human Liver Normal (Mar11) Both Sexes"
],
[
- "383",
- "HLCM_0311",
- "GSE9588 Human Liver Normal (Mar11) Males"
- ],
- [
"384",
"HLCF_0311",
"GSE9588 Human Liver Normal (Mar11) Females"
+ ],
+ [
+ "383",
+ "HLCM_0311",
+ "GSE9588 Human Liver Normal (Mar11) Males"
]
],
"Phenotypes": [
@@ -1718,16 +1718,16 @@
"OHSU/VA B6D2F2 Brain mRNA M430 (Aug05) MAS5"
],
[
- "77",
- "BRF2_M_0805_R",
- "OHSU/VA B6D2F2 Brain mRNA M430 (Aug05) RMA"
- ],
- [
"78",
"BRF2_M_0805_P",
"OHSU/VA B6D2F2 Brain mRNA M430 (Aug05) PDNN"
],
[
+ "77",
+ "BRF2_M_0805_R",
+ "OHSU/VA B6D2F2 Brain mRNA M430 (Aug05) RMA"
+ ],
+ [
"33",
"BRF2_M_0304_P",
"OHSU/VA B6D2F2 Brain mRNA M430A (Mar04) PDNN"
@@ -1824,30 +1824,30 @@
"OHSU/VA B6D2F2 Striatum M430v2 (Sep05) MAS5"
],
[
- "84",
- "SA_M2_0905_R",
- "OHSU/VA B6D2F2 Striatum M430v2 (Sep05) RMA"
- ],
- [
"85",
"SA_M2_0905_P",
"OHSU/VA B6D2F2 Striatum M430v2 (Sep05) PDNN"
+ ],
+ [
+ "84",
+ "SA_M2_0905_R",
+ "OHSU/VA B6D2F2 Striatum M430v2 (Sep05) RMA"
]
]
},
"BHF2": {
"Adipose mRNA": [
[
- "196",
- "UCLA_BHF2_ADIPOSE_MALE",
- "UCLA BHF2 Adipose Male mlratio"
- ],
- [
"197",
"UCLA_BHF2_ADIPOSE_FEMALE",
"UCLA BHF2 Adipose Female mlratio"
],
[
+ "196",
+ "UCLA_BHF2_ADIPOSE_MALE",
+ "UCLA BHF2 Adipose Male mlratio"
+ ],
+ [
"165",
"UCLA_BHF2_ADIPOSE_0605",
"UCLA BHF2 Adipose (June05) mlratio"
@@ -1855,16 +1855,16 @@
],
"Brain mRNA": [
[
- "198",
- "UCLA_BHF2_BRAIN_MALE",
- "UCLA BHF2 Brain Male mlratio"
- ],
- [
"199",
"UCLA_BHF2_BRAIN_FEMALE",
"UCLA BHF2 Brain Female mlratio"
],
[
+ "198",
+ "UCLA_BHF2_BRAIN_MALE",
+ "UCLA BHF2 Brain Male mlratio"
+ ],
+ [
"166",
"UCLA_BHF2_BRAIN_0605",
"UCLA BHF2 Brain (June05) mlratio"
@@ -1879,16 +1879,16 @@
],
"Liver mRNA": [
[
- "200",
- "UCLA_BHF2_LIVER_MALE",
- "UCLA BHF2 Liver Male mlratio"
- ],
- [
"201",
"UCLA_BHF2_LIVER_FEMALE",
"UCLA BHF2 Liver Female mlratio"
],
[
+ "200",
+ "UCLA_BHF2_LIVER_MALE",
+ "UCLA BHF2 Liver Male mlratio"
+ ],
+ [
"167",
"UCLA_BHF2_LIVER_0605",
"UCLA BHF2 Liver (June05) mlratio"
@@ -2016,7 +2016,7 @@
[
"779",
"EL_BXDCDScWAT_0216",
- "EPFL/LISP BXD CD Subcutaneous WAT Affy MTA 1.0 Gene Level (Feb16) RMA **"
+ "EPFL/LISP BXD CD Subcutaneous WAT Affy MTA 1.0 Gene Level (Feb16) RMA"
]
],
"Adrenal Gland mRNA": [
@@ -2122,9 +2122,9 @@
"UTHSC Brain mRNA U74Av2 (Nov05) PDNN"
],
[
- "80",
- "BR_U_0805_M",
- "UTHSC Brain mRNA U74Av2 (Aug05) MAS5"
+ "82",
+ "BR_U_0805_R",
+ "UTHSC Brain mRNA U74Av2 (Aug05) RMA"
],
[
"81",
@@ -2132,9 +2132,9 @@
"UTHSC Brain mRNA U74Av2 (Aug05) PDNN"
],
[
- "82",
- "BR_U_0805_R",
- "UTHSC Brain mRNA U74Av2 (Aug05) RMA"
+ "80",
+ "BR_U_0805_M",
+ "UTHSC Brain mRNA U74Av2 (Aug05) MAS5"
],
[
"42",
@@ -2238,16 +2238,16 @@
"Eye M430v2 Mutant Tyrp1 (Sep08) RMA"
],
[
- "279",
- "Eye_M2_0908_R_WT",
- "Eye M430v2 WT Tyrp1 (Sep08) RMA"
- ],
- [
"382",
"Eye_M2_0908_WTWT",
"Eye M430v2 WT WT (Sep08) RMA"
],
[
+ "279",
+ "Eye_M2_0908_R_WT",
+ "Eye M430v2 WT Tyrp1 (Sep08) RMA"
+ ],
+ [
"400",
"DBA2J-ONH-1212",
"Howell et al. 2011, DBA/2J Glaucoma Optic Nerve Head M430 2.0 (Dec12) RMA"
@@ -2531,16 +2531,16 @@
],
"Kidney mRNA": [
[
- "239",
- "MA_M2F_0706_R",
- "Mouse kidney M430v2 Female (Aug06) RMA"
- ],
- [
"240",
"MA_M2M_0706_R",
"Mouse kidney M430v2 Male (Aug06) RMA"
],
[
+ "239",
+ "MA_M2F_0706_R",
+ "Mouse kidney M430v2 Female (Aug06) RMA"
+ ],
+ [
"118",
"MA_M2_0806_R",
"Mouse kidney M430v2 Sex Balanced (Aug06) RMA"
@@ -2563,6 +2563,26 @@
],
"Liver Metabolome": [
[
+ "838",
+ "UTHSC-ETHZ-EPFL_LivPMetExtBHFD0817",
+ "UTHSC/ETHZ/EPFL BXD Liver Polar Metabolites Extraction B, HFD Cohorts (Mar 2017) log2"
+ ],
+ [
+ "835",
+ "UTHSC-ETHZ-EPFL_LivPMetExtACD0817",
+ "UTHSC/ETHZ/EPFL BXD Liver Polar Metabolites Extraction A, Chow Diet Cohorts (Mar 2017) log2"
+ ],
+ [
+ "837",
+ "UTHSC-ETHZ-EPFL_LivPMetExtBCD0817",
+ "UTHSC/ETHZ/EPFL BXD Liver Polar Metabolites Extraction B, Chow Diet Cohorts (Mar 2017) log2"
+ ],
+ [
+ "836",
+ "UTHSC-ETHZ-EPFL_LivPMetExtAHFD0817",
+ "UTHSC/ETHZ/EPFL BXD Liver Polar Metabolites Extraction A, HFD Cohorts (Mar 2017) log2"
+ ],
+ [
"473",
"EPFL-LISP_LivPMetCDHFD1213",
"EPFL/LISP BXD Liver Polar Metabolites CD+HFD (Jun14)"
@@ -2632,19 +2652,29 @@
"EPFL/LISP BXD CD+HFD Liver Affy Mouse Gene 1.0 ST (Aug18) RMA"
],
[
+ "858",
+ "EPFLMouseLiverHFDRMA0818",
+ "EPFL/LISP BXD HFD Liver Affy Mouse Gene 1.0 ST (Aug18) RMA"
+ ],
+ [
"859",
"EPFLMouseLiverCDRMA0818",
"EPFL/LISP BXD CD Liver Affy Mouse Gene 1.0 ST (Aug18) RMA"
],
[
- "851",
- "NIA-AgBXD-Liv_CDHFD-0818",
- "NIA Aging BXD CD+HFD Liver Affy Clariom S Gene Level (Aug18) RMA **"
+ "854",
+ "NIA-AgBXD-Liv_CDHFD-rna-seq-0818",
+ "NIA Aging BXD CD+HFD Liver RNA-Seq (Aug18) Log2"
+ ],
+ [
+ "855",
+ "NIA-AgBXD-Liv_HFD-rna-seq-0818",
+ "NIA Aging BXD HFD Liver RNA-Seq (Aug18) Log2"
],
[
- "853",
- "NIA-AgBXD-Liv_CD-0818",
- "NIA Aging BXD CD Liver Affy Clariom S Gene Level (Aug18) RMA **"
+ "856",
+ "NIA-AgBXD-Liv_CD-rna-seq-0818",
+ "NIA Aging BXD CD Liver RNA-Seq (Aug18) Log2"
],
[
"818",
@@ -2652,16 +2682,6 @@
"UCLA BXD Liver Affy M430 2.0 (Jan16) RMA"
],
[
- "858",
- "EPFLMouseLiverHFDRMA0818",
- "EPFL/LISP BXD HFD Liver Affy Mouse Gene 1.0 ST (Aug18) RMA"
- ],
- [
- "852",
- "NIA-AgBXD-Liv_HFD-0818",
- "NIA Aging BXD HFD Liver Affy Clariom S Gene Level (Aug18) RMA **"
- ],
- [
"430",
"EPFLMouseLiverRMA0413",
"EPFL/LISP BXD CD+HFD Liver Affy Mouse Gene 1.0 ST (Apr13) RMA"
@@ -2672,9 +2692,9 @@
"EPFL/LISP BXD HFD Liver Affy Mouse Gene 1.0 ST (Apr13) RMA"
],
[
- "432",
- "EPFLMouseLiverCDRMA0413",
- "EPFL/LISP BXD CD Liver Affy Mouse Gene 1.0 ST (Apr13) RMA"
+ "849",
+ "EPFLMouseLiverCDEx0413",
+ "EPFL/LISP BXD CD Liver Affy Mouse Gene 1.0 ST (Apr13) RMA Exon Level"
],
[
"848",
@@ -2682,16 +2702,16 @@
"EPFL/LISP BXD HFC Liver Affy Mouse Gene 1.0 ST (Apr13) RMA Exon Level"
],
[
+ "432",
+ "EPFLMouseLiverCDRMA0413",
+ "EPFL/LISP BXD CD Liver Affy Mouse Gene 1.0 ST (Apr13) RMA"
+ ],
+ [
"433",
"EPFLMouseLiverBothExRMA0413",
"EPFL/LISP BXD CD+HFD Liver Affy Mouse Gene 1.0 ST (Apr13) RMA Exon Level"
],
[
- "849",
- "EPFLMouseLiverCDEx0413",
- "EPFL/LISP BXD CD Liver Affy Mouse Gene 1.0 ST (Apr13) RMA Exon Level"
- ],
- [
"700",
"UTHSC-VGX_MmBXDHepatocytesRMA1014",
"UT-VGX Hepatocytes Affy Mouse Gene 1.0 ST Gene Level (Oct14) RMA"
@@ -2840,14 +2860,14 @@
"HQF BXD Neocortex ILM6v1.1 (Feb08) RankInv"
],
[
- "274",
- "DevNeocortex_ILM6.2P3RInv_1110",
- "BIDMC/UTHSC Dev Neocortex P3 ILMv6.2 (Nov10) RankInv"
- ],
- [
"275",
"DevNeocortex_ILM6.2P14RInv_1110",
"BIDMC/UTHSC Dev Neocortex P14 ILMv6.2 (Nov10) RankInv"
+ ],
+ [
+ "274",
+ "DevNeocortex_ILM6.2P3RInv_1110",
+ "BIDMC/UTHSC Dev Neocortex P3 ILMv6.2 (Nov10) RankInv"
]
],
"Nucleus Accumbens mRNA": [
@@ -3080,14 +3100,14 @@
"VCU BXD VTA Sal M430 2.0 (Jun09) RMA"
],
[
- "229",
- "VCUEtOH_0609_R",
- "VCU BXD VTA EtOH M430 2.0 (Jun09) RMA"
- ],
- [
"230",
"VCUEtvsSal_0609_R",
"VCU BXD VTA Et vs Sal M430 2.0 (Jun09) RMA"
+ ],
+ [
+ "229",
+ "VCUEtOH_0609_R",
+ "VCU BXD VTA EtOH M430 2.0 (Jun09) RMA"
]
]
},
@@ -3105,17 +3125,7 @@
[
"843",
"UTHSC-BXD-Harv_Liv-0118",
- "UTHSC BXD Harvested Liver RNA-Seq (Aug18) Log2 **"
- ],
- [
- "842",
- "UTHSC-BXD-Liv-0917",
- "UTHSC BXD Liver Affy Clariom S GeneLevel Main (Sep17) RMA **"
- ],
- [
- "850",
- "UTHSC-BXD-Liv-0818",
- "UTHSC BXD Liver Affy Clariom S GeneLevel Main (Aug18) RMA **"
+ "UTHSC BXD Harvested Liver RNA-Seq (Aug18) Log2"
]
],
"Phenotypes": [
@@ -3522,26 +3532,26 @@
],
"Hippocampus mRNA": [
[
- "211",
- "Illum_LXS_Hipp_RSS_1008",
- "Hippocampus Illumina RSS (Oct08) RankInv beta"
- ],
- [
"212",
"Illum_LXS_Hipp_RSE_1008",
"Hippocampus Illumina RSE (Oct08) RankInv beta"
],
[
- "213",
- "Illum_LXS_Hipp_NOS_1008",
- "Hippocampus Illumina NOS (Oct08) RankInv beta"
- ],
- [
"214",
"Illum_LXS_Hipp_NOE_1008",
"Hippocampus Illumina NOE (Oct08) RankInv beta"
],
[
+ "211",
+ "Illum_LXS_Hipp_RSS_1008",
+ "Hippocampus Illumina RSS (Oct08) RankInv beta"
+ ],
+ [
+ "213",
+ "Illum_LXS_Hipp_NOS_1008",
+ "Hippocampus Illumina NOS (Oct08) RankInv beta"
+ ],
+ [
"219",
"Illum_LXS_Hipp_NON_1008",
"Hippocampus Illumina NON (Oct08) RankInv beta"
@@ -3708,16 +3718,16 @@
"Retina-RGC-Rheaume": {
"Retina Single-cell RNA-Seq": [
[
- "866",
- "UConn-RGC-RSeq_log2-0918",
- "UConn-Rheaume Retina RGC (Sep18) scRNA-Seq Log2"
- ],
- [
"865",
"UConn-RGC-RSeq_r-0918",
"UConn-Rheaume Retina RGC (Sep18) scRNA-Seq Raw"
],
[
+ "866",
+ "UConn-RGC-RSeq_log2-0918",
+ "UConn-Rheaume Retina RGC (Sep18) scRNA-Seq Log2"
+ ],
+ [
"867",
"UConn-RGC-RSeq_s-0918",
"UConn-Rheaume Retina RGC (Sep18) scRNA-Seq Siamak"
diff --git a/wqflask/wqflask/static/new/javascript/network_graph.js b/wqflask/wqflask/static/new/javascript/network_graph.js
index 0ecf4743..bc02181f 100644
--- a/wqflask/wqflask/static/new/javascript/network_graph.js
+++ b/wqflask/wqflask/static/new/javascript/network_graph.js
@@ -1,18 +1,9 @@
-window.onload=function() {
- // id of Cytoscape Web container div
- //var div_id = "cytoscapeweb";
-
- var cy = cytoscape({
- container: $('#cytoscapeweb'), // container to render in
-
- elements: elements_list,
-
- style: [ // the stylesheet for the graph
+var default_style = [ // the stylesheet for the graph
{
selector: 'node',
style: {
'background-color': '#666',
- 'label': 'data(label )',
+ 'label': 'data(label)',
'font-size': 10
}
},
@@ -27,16 +18,28 @@ window.onload=function() {
'font-size': 8
}
}
- ],
-
- zoom: 12,
- layout: { name: 'circle',
+ ]
+
+var default_layout = { name: 'circle',
fit: true, // whether to fit the viewport to the graph
padding: 30 // the padding on fit
//idealEdgeLength: function( edge ){ return edge.data['correlation']*10; },
- },
+ }
+
+window.onload=function() {
+ // id of Cytoscape Web container div
+ //var div_id = "cytoscapeweb";
+ var cy = cytoscape({
+ container: $('#cytoscapeweb'), // container to render in
+
+ elements: elements_list,
+ style: default_style,
+
+ zoom: 12,
+ layout: default_layout,
+
zoomingEnabled: true,
userZoomingEnabled: true,
panningEnabled: true,
@@ -131,22 +134,25 @@ window.onload=function() {
create_qtips(cy)
- $('#slide').change(function() {
+ $('#neg_slide').change(function() {
eles.restore()
+
+ pos_slide_val = $('#pos_slide').val();
+ cy.$("node[max_corr > " + $(this).val() + "][max_corr < " + pos_slide_val + "]").remove();
+ cy.$("edge[correlation > " + $(this).val() + "][correlation < " + pos_slide_val + "]").remove();
+
+ cy.layout({ name: $('select[name=layout_select]').val(),
+ fit: true, // whether to fit the viewport to the graph
+ padding: 25 // the padding on fit
+ });
- console.log(eles)
-
- // nodes_to_restore = eles.filter("node[max_corr >= " + $(this).val() + "], edge[correlation >= " + $(this).val() + "][correlation <= -" + $(this).val() + "]")
- // nodes_to_restore.restore()
-
- // edges_to_restore = eles.filter("edge[correlation >= " + $(this).val() + "][correlation <= -" + $(this).val() + "]")
- // edges_to_restore.restore()
-
- //cy.$("node[max_corr >= " + $(this).val() + "]").restore();
- //cy.$("edge[correlation >= " + $(this).val() + "][correlation <= -" + $(this).val() + "]").restore();
-
- cy.$("node[max_corr < " + $(this).val() + "]").remove();
- cy.$("edge[correlation < " + $(this).val() + "][correlation > -" + $(this).val() + "]").remove();
+ });
+ $('#pos_slide').change(function() {
+ eles.restore()
+
+ neg_slide_val = $('#neg_slide').val();
+ cy.$("node[max_corr > " + neg_slide_val +"][max_corr < " + $(this).val() + "]").remove();
+ cy.$("edge[correlation > " + neg_slide_val +"][correlation < " + $(this).val() + "]").remove();
cy.layout({ name: $('select[name=layout_select]').val(),
fit: true, // whether to fit the viewport to the graph
@@ -157,7 +163,8 @@ window.onload=function() {
$('#reset_graph').click(function() {
eles.restore()
- $('#slide').val(0)
+ $('#pos_slide').val(0)
+ $('#neg_slide').val(0)
cy.layout({ name: $('select[name=layout_select]').val(),
fit: true, // whether to fit the viewport to the graph
padding: 25 // the padding on fit
@@ -178,13 +185,67 @@ window.onload=function() {
$('select[name=layout_select]').change(function() {
layout_type = $(this).val()
- console.log("LAYOUT:", layout_type)
cy.layout({ name: layout_type,
fit: true, // whether to fit the viewport to the graph
padding: 25 // the padding on fit
});
});
+ $('select[name=font_size]').change(function() {
+ font_size = $(this).val()
+
+ new_style = default_style
+ new_style[0]['style']['font-size'] = parseInt(font_size)
+ cy.style().fromJson(new_style).update()
+ });
+ $('select[name=edge_width]').change(function() {
+ //eles.restore()
+
+ //ZS: This is needed, or else it alters the original object
+ orig_elements = JSON.parse(JSON.stringify(elements_list));
+
+ width_multiplier = $(this).val()
+ updated_elements = []
+ for (i=0; i < orig_elements.length; i++){
+ this_element = orig_elements[i]
+ if ('source' in this_element['data']) {
+ orig_width = this_element['data']['width']
+ this_element['data']['width'] = orig_width * width_multiplier
+ }
+ updated_elements.push(this_element)
+ }
+ cy.remove(eles)
+ cy.add(updated_elements)
+ cy.layout({ name: $('select[name=layout_select]').val(),
+ fit: true, // whether to fit the viewport to the graph
+ padding: 25 // the padding on fit
+ });
+ });
+
+ $('select[name=edge_width]').change(function() {
+ //eles.restore()
+
+ //ZS: This is needed, or else it alters the original object
+ orig_elements = JSON.parse(JSON.stringify(elements_list));
+
+ width_multiplier = $(this).val()
+ updated_elements = []
+ for (i=0; i < orig_elements.length; i++){
+ this_element = orig_elements[i]
+ if ('source' in this_element['data']) {
+ orig_width = this_element['data']['width']
+ this_element['data']['width'] = orig_width * width_multiplier
+ }
+ updated_elements.push(this_element)
+ }
+ cy.remove(eles)
+ cy.add(updated_elements)
+ cy.layout({ name: $('select[name=layout_select]').val(),
+ fit: true, // whether to fit the viewport to the graph
+ padding: 25 // the padding on fit
+ });
+ });
+
$("a#image_link").click(function(e) {
var pngData = cy.png();
diff --git a/wqflask/wqflask/templates/collections/list.html b/wqflask/wqflask/templates/collections/list.html
index 64d5a676..5a2df5e3 100644
--- a/wqflask/wqflask/templates/collections/list.html
+++ b/wqflask/wqflask/templates/collections/list.html
@@ -4,6 +4,7 @@
<link rel="stylesheet" type="text/css" href="/static/new/packages/DataTables/css/jquery.dataTables.css" />
<link rel="stylesheet" type="text/css" href="/static/packages/DT_bootstrap/DT_bootstrap.css" />
<link rel="stylesheet" type="text/css" href="/static/new/packages/DataTables/extensions/buttons.bootstrap.css" />
+ <link rel="stylesheet" type="text/css" href="/static/new/css/show_trait.css" />
{% endblock %}
{% block content %}
<!-- Start of body -->
@@ -15,7 +16,6 @@
'You have {}.'.format(numify(collections|count, "collection", "collections"))) }}
{% endif %}
-
<div class="container">
<div class="page-header">
{% if g.user_session.logged_in %}
@@ -35,7 +35,7 @@
</div>
<br>
<div id="collections_list" style="width:50%;">
- <table class="display dataTable nowrap" id='trait_table'>
+ <table class="table-hover table-striped cell-border" id='trait_table'>
<thead>
<tr>
<th></th>
@@ -51,9 +51,9 @@
{% for uc in collections %}
<tr class="collection_line">
{% if g.user_session.logged_in %}
- <td style="padding-left: 8px; padding-right: 0px; padding-top: 4px; align: center;"><INPUT TYPE="checkbox" NAME="collection" class="checkbox trait_checkbox" VALUE="{{ uc.id }}"></td>
+ <td align="center" style="padding: 0px;"><INPUT TYPE="checkbox" NAME="collection" class="checkbox trait_checkbox" VALUE="{{ uc.id }}"></td>
{% else %}
- <td style="padding-left: 8px; padding-right: 0px; padding-top: 4px; align: center;"><INPUT TYPE="checkbox" NAME="collection" class="checkbox trait_checkbox" VALUE="{{ uc.name }}"></td>
+ <td align="center" style="padding: 0px;"><INPUT TYPE="checkbox" NAME="collection" class="checkbox trait_checkbox" VALUE="{{ uc.name }}"></td>
{% endif %}
<td align="right">{{ loop.index }}
{% if g.user_session.logged_in %}
diff --git a/wqflask/wqflask/templates/collections/view.html b/wqflask/wqflask/templates/collections/view.html
index 864299a2..b6ad7be8 100644
--- a/wqflask/wqflask/templates/collections/view.html
+++ b/wqflask/wqflask/templates/collections/view.html
@@ -3,6 +3,7 @@
{% block css %}
<link rel="stylesheet" type="text/css" href="/static/new/packages/DataTables/css/jquery.dataTables.css" />
<link rel="stylesheet" type="text/css" href="/static/new/packages/DataTables/extensions/buttons.dataTables.css">
+ <link rel="stylesheet" type="text/css" href="/static/new/css/show_trait.css" />
{% endblock %}
{% block content %}
<!-- Start of body -->
@@ -82,7 +83,7 @@
</form>
<br />
<div>
- <table class="display dataTable nowrap" id='trait_table' style="float: left;">
+ <table class="table-hover table-striped cell-border" id='trait_table' style="float: left;">
<thead>
<tr>
<th></th>
@@ -92,21 +93,21 @@
<th data-export="Description">Description</th>
<th data-export="Location">Location</th>
<th data-export="Mean">Mean</th>
- <th data-export="Max LRS">Max LRS <a href="http://genenetwork.org//glossary.html#L" target="_blank"><img style="width: 15px; height: 15px;" src="/static/new/images/question_mark.jpg"></a></th>
+ <th data-export="Max LRS">Max LRS <a href="http://genenetwork.org//glossary.html#L" target="_blank"><sup>?</sup></a></th>
<th data-export="Max LRS Location">Max LRS Location</th>
- <th data-export="Additive Effect">Additive Effect <a href="http://genenetwork.org//glossary.html#A" target="_blank"><img style="width: 15px; height: 15px;" src="/static/new/images/question_mark.jpg"></a></th>
+ <th data-export="Add. Eff.">Additive Effect <a href="http://genenetwork.org//glossary.html#A" target="_blank"><sup>?</sup></a></th>
</tr>
</thead>
<tbody>
{% for this_trait in trait_obs %}
<TR id="trait:{{ this_trait.name }}:{{ this_trait.dataset.name }}">
- <TD>
+ <TD align="center" style="padding: 0px;">
<INPUT TYPE="checkbox" NAME="searchResult" class="checkbox trait_checkbox"
VALUE="{{ data_hmac('{}:{}'.format(this_trait.name, this_trait.dataset.name)) }}">
</TD>
<TD data-export="{{ loop.index }}" align="right">{{ loop.index }}</TD>
- <TD data-export="{{ this_trait.dataset.name }}">{{ this_trait.dataset.name }}</TD>
+ <TD title="{{ this_trait.dataset.fullname }}" data-export="{{ this_trait.dataset.fullname }}">{{ this_trait.dataset.fullname }}</TD>
<TD data-export="{{ this_trait.name }}">
<a href="{{ url_for('show_trait_page',
trait_id = this_trait.name,
@@ -159,23 +160,26 @@
console.time("Creating table");
$('#trait_table').dataTable( {
"createdRow": function ( row, data, index ) {
- $('td', row).eq(0).attr('style', 'padding-left: 8px; padding-right: 0px; padding-top: 4px; align: center;');
+ if ($('td', row).eq(2).text().length > 40) {
+ $('td', row).eq(2).text($('td', row).eq(2).text().substring(0, 40));
+ $('td', row).eq(2).text($('td', row).eq(2).text() + '...')
+ }
if ($('td', row).eq(4).text().length > 50) {
$('td', row).eq(4).text($('td', row).eq(4).text().substring(0, 50));
$('td', row).eq(4).text($('td', row).eq(4).text() + '...')
}
},
"columns": [
- { "type": "natural", "width": "2%" },
- { "type": "natural", "width": "5%" },
- { "type": "natural", "width": "12%" },
- { "type": "natural", "width": "12%" },
+ { "type": "natural", "width": 10 },
+ { "type": "natural", "width": 50 },
+ { "type": "natural" },
+ { "type": "natural", "width": 120 },
{ "type": "natural" },
- { "type": "natural", "width": "12%" },
- { "type": "natural", "width": "5%" },
- { "type": "natural", "width": "5%" },
- { "type": "natural", "width": "12%" },
- { "type": "natural", "width": "8%" }
+ { "type": "natural", "width": 130 },
+ { "type": "natural", "width": 35 },
+ { "type": "natural", "width": 35 },
+ { "type": "natural", "width": 130 },
+ { "type": "natural" }
],
"columnDefs": [ {
"targets": 0,
@@ -194,8 +198,6 @@
"autoWidth": false,
"bDeferRender": true,
"bSortClasses": false,
- "scrollY": "600px",
- "scrollCollapse": true,
"paging": false,
"orderClasses": true
} );
diff --git a/wqflask/wqflask/templates/gsearch_gene.html b/wqflask/wqflask/templates/gsearch_gene.html
index 0612bfcc..ff5c56f1 100644
--- a/wqflask/wqflask/templates/gsearch_gene.html
+++ b/wqflask/wqflask/templates/gsearch_gene.html
@@ -2,6 +2,7 @@
{% block title %}Search Results{% endblock %}
{% block css %}
<link rel="stylesheet" type="text/css" href="/static/new/packages/DataTables/css/jquery.dataTables.css" />
+ <link rel="stylesheet" type="text/css" href="/static/new/css/show_trait.css" />
{% endblock %}
{% block content %}
<!-- Start of body -->
@@ -28,7 +29,7 @@
</form>
<br />
<div style="width: 100%;">
- <table width="100%" id="trait_table" class="display dataTable nowrap" style="float: left;">
+ <table id="trait_table" class="table-hover table-striped cell-border" style="float: left;">
<thead>
<tr>
<th></th>
@@ -42,14 +43,14 @@
<th data-export="Description">Description</th>
<th data-export="Location">Location</th>
<th data-export="Mean">Mean</th>
- <th data-export="Max LRS">Max LRS <a href="http://genenetwork.org//glossary.html#LRS" target="_blank"><img style="width: 15px; height: 15px;" src="/static/new/images/question_mark.jpg"></a></th>
- <th data-export="Additive Effect">Additive Effect <a href="http://genenetwork.org//glossary.html#A" target="_blank"><img style="width: 15px; height: 15px;" src="/static/new/images/question_mark.jpg"></a></th>
+ <th data-export="Max LRS">Max LRS <a href="http://genenetwork.org//glossary.html#LRS" target="_blank" style="color: white;"><sup>?</sup></a></th>
+ <th data-export="Additive Effect">Additive Effect <a href="http://genenetwork.org//glossary.html#A" target="_blank" style="color: white;"><sup>?</sup></a></th>
</tr>
</thead>
<tbody>
{% for this_trait in trait_list %}
<tr id="trait:{{ this_trait.name }}:{{ this_trait.dataset }}">
- <td align="center" style="padding-right: 0px; padding-left: 5px;"><input type="checkbox" name="searchResult" class="checkbox trait_checkbox" value="{{ data_hmac('{}:{}'.format(this_trait.name, this_trait.dataset)) }}"></td>
+ <td align="center" style="padding: 0px;"><input type="checkbox" name="searchResult" class="checkbox trait_checkbox" value="{{ data_hmac('{}:{}'.format(this_trait.name, this_trait.dataset)) }}"></td>
<td align="right" data-export="{{ loop.index }}">{{ loop.index }}</td>
<td data-export="{{ this_trait.name }}"><a href="{{ url_for('show_trait_page', trait_id = this_trait.name, dataset = this_trait.dataset)}}">{{ this_trait.name }}</a></td>
<td data-export="{{ this_trait.species }}">{{ this_trait.species }}</td>
@@ -78,8 +79,8 @@
<th>Description</th>
<th>Location</th>
<th>Mean</th>
- <th data-export="Max LRS">Max LRS <a href="http://genenetwork.org//glossary.html#LRS" target="_blank"><img style="width: 15px; height: 15px;" src="/static/new/images/question_mark.jpg"></a></th>
- <th data-export="Additive Effect">Additive Effect <a href="http://genenetwork.org//glossary.html#A" target="_blank"><img style="width: 15px; height: 15px;" src="/static/new/images/question_mark.jpg"></a></th>
+ <th data-export="Max LRS">Max LRS <a href="http://genenetwork.org//glossary.html#LRS" target="_blank" style="color: white;"><sup>?</sup></a></th>
+ <th data-export="Additive Effect">Additive Effect <a href="http://genenetwork.org//glossary.html#A" target="_blank" style="color: white;"><sup>?</sup></a></th>
</tr>
</tfoot>
</table>
diff --git a/wqflask/wqflask/templates/gsearch_pheno.html b/wqflask/wqflask/templates/gsearch_pheno.html
index c2cbdadd..01b2403e 100644
--- a/wqflask/wqflask/templates/gsearch_pheno.html
+++ b/wqflask/wqflask/templates/gsearch_pheno.html
@@ -2,6 +2,7 @@
{% block title %}Search Results{% endblock %}
{% block css %}
<link rel="stylesheet" type="text/css" href="/static/new/packages/DataTables/css/jquery.dataTables.css" />
+ <link rel="stylesheet" type="text/css" href="/static/new/css/show_trait.css" />
{% endblock %}
{% block content %}
<!-- Start of body -->
@@ -28,7 +29,7 @@
</form>
<br />
<div>
- <table id="trait_table" class="display dataTable nowrap" style="float: left;">
+ <table id="trait_table" class="table-hover table-striped cell-border" style="float: left;">
<thead>
<tr>
<th></th>
@@ -39,8 +40,8 @@
<th data-export="Description">Description</th>
<th data-export="Authors">Authors</th>
<th data-export="Year">Year</th>
- <th data-export="Max LRS">Max LRS <a href="http://genenetwork.org//glossary.html#LRS" target="_blank"><img style="width: 15px; height: 15px;" src="/static/new/images/question_mark.jpg"></a></th>
- <th data-export="Additive Effect">Additive Effect <a href="http://genenetwork.org//glossary.html#A" target="_blank"><img style="width: 15px; height: 15px;" src="/static/new/images/question_mark.jpg"></a></th>
+ <th data-export="Max LRS">Max LRS <a href="http://genenetwork.org//glossary.html#LRS" target="_blank"><sup>?</sup></a></th>
+ <th data-export="Additive Effect">Additive Effect <a href="http://genenetwork.org//glossary.html#A" target="_blank"><sup>?</sup></a></th>
</tr>
</thead>
<tbody>
@@ -55,7 +56,7 @@
<td data-export="{{ this_trait.authors }}">{{ this_trait.authors }}</td>
<td data-export="{{ this_trait.pubmed_text }}" data-order="{{ this_trait.pubmed_text }}"><a href="{{ this_trait.pubmed_link }}">{{ this_trait.pubmed_text }}</a></td>
<td data-export="{% if this_trait.LRS_score_repr != "N/A" %}{{ '%0.1f' % this_trait.LRS_score_repr|float }}{% else %}N/A{% endif %}" align="right">{% if this_trait.LRS_score_repr != "N/A" %}{{ '%0.1f' % this_trait.LRS_score_repr|float }}{% else %}N/A{% endif %}</td>
- <td data-export="{% if this_trait.additive != "" %}{{ this_trait.additive }}{% else %}N/A{% endif %}" align="right">{% if this_trait.additive != "" %}{{ this_trait.additive }}{% else %}N/A{% endif %}</td>
+ <td data-export="{% if this_trait.additive %}{{ this_trait.additive }}{% else %}N/A{% endif %}" align="right">{% if this_trait.additive %}{{ '%0.6f' % this_trait.additive }}{% else %}N/A{% endif %}</td>
</tr>
{% endfor %}
</tbody>
@@ -110,14 +111,16 @@
console.time("Creating table");
$('#trait_table').DataTable( {
"createdRow": function ( row, data, index ) {
+ $('td', row).eq(0).attr('style', 'padding: 0px;');
+ $('td', row).eq(0).attr('align', 'center');
$('td', row).eq(5).attr('title', $('td', row).eq(5).text());
if ($('td', row).eq(5).text().length > 50) {
$('td', row).eq(5).text($('td', row).eq(5).text().substring(0, 50));
$('td', row).eq(5).text($('td', row).eq(5).text() + '...')
}
$('td', row).eq(6).attr('title', $('td', row).eq(6).text());
- if ($('td', row).eq(6).text().length > 50) {
- $('td', row).eq(6).text($('td', row).eq(6).text().substring(0, 50));
+ if ($('td', row).eq(6).text().length > 40) {
+ $('td', row).eq(6).text($('td', row).eq(6).text().substring(0, 40));
$('td', row).eq(6).text($('td', row).eq(6).text() + '...')
}
},
@@ -128,11 +131,11 @@
{ "type": "natural" },
{ "type": "natural" },
{ "type": "natural" },
- { "type": "natural", "width": "30%"},
- { "type": "natural", "width": "25%"},
{ "type": "natural" },
- { "type": "natural", "width": "8%"},
- { "type": "natural" }
+ { "type": "natural" },
+ { "type": "natural" },
+ { "type": "natural", "width": "5%"},
+ { "type": "natural", "width": "8%" }
],
"columnDefs": [
{
diff --git a/wqflask/wqflask/templates/mapping_results.html b/wqflask/wqflask/templates/mapping_results.html
index 00d725ea..3138d855 100644
--- a/wqflask/wqflask/templates/mapping_results.html
+++ b/wqflask/wqflask/templates/mapping_results.html
@@ -181,7 +181,7 @@
</form>
{% if selectedChr == -1 %}
- <div class="container" style="padding-left: 30px; width:{% if 'additive' in trimmed_markers[0] %}45%{% else %}35%{% endif %};">
+ <div class="container" style="padding-left: 30px;">
<h2>Mapping Statistics</h2>
<br />
<button class="btn btn-default" id="select_all"><span class="glyphicon glyphicon-ok"></span> Select All</button>
@@ -190,8 +190,8 @@
<button class="btn btn-default" id="add" disabled><span class="glyphicon glyphicon-plus-sign"></span> Add</button>
<br />
<br />
- <div id="table_container" style="border-style: solid; border-width: 1px; border-color: black;">
- <table id="trait_table" class="table table-hover table-striped nowrap">
+ <div id="table_container" style="width:{% if 'additive' in trimmed_markers[0] %}480{% else %}450{% endif %}px;">
+ <table id="trait_table" class="table-hover table-striped cell-border dataTable no-footer">
<thead>
<tr>
<th></th>
@@ -215,7 +215,7 @@
<tbody>
{% for marker in trimmed_markers %}
<tr>
- <td align="center" style="padding-right: 0px;">
+ <td align="center" style="padding-right: 0px; padding-left: 0px;">
<input type="checkbox" name="selectCheck"
class="checkbox trait_checkbox"
value="{{ data_hmac('{}:{}Geno'.format(marker.name, dataset.group.name)) }}">
@@ -257,7 +257,7 @@
<div style="width: 100%;">
<h2>Interval Analyst</h2>
<div id="table_container">
- <table id="interval_analyst" class="table-hover table-striped cell-border" style="float: left; width:100%;">
+ <table id="interval_analyst" class="table-hover table-striped cell-border dataTable" style="float: left; width:100%;">
<thead>
<tr>
{% for header in gene_table_header %}
@@ -314,37 +314,16 @@
$(document).ready( function () {
console.time("Creating table");
$('#trait_table').DataTable( {
- {% if mapping_method != "reaper" %}
"columns": [
{ "type": "natural", "width": "5%" },
{ "type": "natural", "width": "8%" },
- { "type": "natural", "width": "20%" },
+ { "type": "natural", "width": "25%" },
+ { "type": "natural" },
{ "type": "natural", "width": "8%" },
- { "type": "natural", "width": "8%" },
- { "type": "natural", "width": "15%" }
- ],
- {% elif dataset.group.genetic_type == "riset" %}
- "columns": [
- { "type": "natural", "width": "5%" },
- { "type": "natural", "width": "8%" },
- { "type": "natural", "width": "20%" },
- { "type": "natural", "width": "8%" },
- { "type": "natural", "width": "8%" },
- { "type": "natural", "width": "15%" },
- { "type": "natural", "width": "8%" }
- ],
- {% else %}
- "columns": [
- { "type": "natural", "width": "5%" },
- { "type": "natural", "width": "8%" },
- { "type": "natural", "width": "20%" },
- { "type": "natural", "width": "8%" },
- { "type": "natural", "width": "8%" },
- { "type": "natural", "width": "15%" },
- { "type": "natural", "width": "8%" },
- { "type": "natural", "width": "8%" }
+ { "type": "natural" }{% if 'additive' in marker %},
+ { "type": "natural" }{% endif %}{% if 'dominance' in marker and dataset.group.genetic_type != "riset" %},
+ { "type": "natural" }{% endif %}
],
- {% endif %}
"columnDefs": [ {
"targets": 0,
"orderable": false
diff --git a/wqflask/wqflask/templates/network_graph.html b/wqflask/wqflask/templates/network_graph.html
index ad5dee9d..57bd5492 100644
--- a/wqflask/wqflask/templates/network_graph.html
+++ b/wqflask/wqflask/templates/network_graph.html
@@ -47,19 +47,16 @@
</tr>
<tr>
<td colspan="1">
- <font size="2"><b>0 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
- &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
- &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; +/- 1</b></font><br>
- <input type="range" id="slide" min="0" max="1" value="0" step="0.001" list="corr_range">
- </td>
- </tr>
- <tr>
- <td>
- Layouts
+ <font size="2"><b>-1 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
+ &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;0&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
+ &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 1</b></font><br>
+ <input type="range" id="neg_slide" min="-1" max="0" value="0" step="0.001" list="corr_range" style="display: inline; width: 45%">
+ <input type="range" id="pos_slide" min="0" max="1" value="0" step="0.001" list="corr_range" style="display: inline; width: 45%">
</td>
</tr>
<tr>
<td>
+ Layouts:
<select name="layout_select">
<option value="circle">Circle</option>
<option value="concentric">Concentric</option>
@@ -70,6 +67,39 @@
</select>
</td>
</tr>
+ <tr>
+ <td>
+ Node Font Size:
+ <select name="font_size">
+ <option value="6">6</option>
+ <option value="7">7</option>
+ <option value="8">8</option>
+ <option value="9">9</option>
+ <option value="10" selected>10</option>
+ <option value="11">11</option>
+ <option value="12">12</option>
+ <option value="13">13</option>
+ <option value="14">14</option>
+ <option value="15">15</option>
+ <option value="16">16</option>
+ <option value="17">17</option>
+ <option value="18">18</option>
+ </select>
+ </td>
+ <td>
+ </tr>
+ <tr>
+ <td>
+ Edge Width:
+ <select name="edge_width">
+ <option value="1" selected>1x</option>
+ <option value="2">2x</option>
+ <option value="3">3x</option>
+ <option value="4">4x</option>
+ </select>
+ </td>
+ <td>
+ </tr>
</tbody>
</table>
<h3 style="margin-bottom: 5px;"> Download</h3>
diff --git a/wqflask/wqflask/templates/search_result_page.html b/wqflask/wqflask/templates/search_result_page.html
index a325ec9f..eaeb7e6b 100644
--- a/wqflask/wqflask/templates/search_result_page.html
+++ b/wqflask/wqflask/templates/search_result_page.html
@@ -79,7 +79,7 @@
-->
<div id="table_container" style="width: {% if dataset.type == 'ProbeSet' %}1300{% elif dataset.type == 'Publish' %}1300{% elif dataset.type == 'Geno' %}400{% endif %}px;">
- <table class="display dataTable nowrap" id='trait_table' style="float: left;">
+ <table class="table-hover table-striped cell-border" id='trait_table' style="float: left;">
<thead>
<tr>
<th></th>
@@ -184,16 +184,21 @@
$('.trait_checkbox:checkbox').on("change", change_buttons);
},
"createdRow": function ( row, data, index ) {
- $('td', row).eq(0).attr('style', 'padding-left: 8px; padding-right: 0px; padding-top: 4px; align: center;');
+ $('td', row).eq(0).attr('style', 'padding: 0px;');
+ $('td', row).eq(0).attr('align', 'center');
$('td', row).eq(1).attr('align', 'right');
$('td', row).eq(1).attr('data-export', index+1);
$('td', row).eq(2).attr('data-export', $('td', row).eq(2).text());
$('td', row).eq(3).attr('title', $('td', row).eq(3).text());
$('td', row).eq(3).attr('data-export', $('td', row).eq(3).text());
+ if ($('td', row).eq(3).text().length > 20) {
+ $('td', row).eq(3).text($('td', row).eq(3).text().substring(0, 20));
+ $('td', row).eq(3).text($('td', row).eq(3).text() + '...')
+ }
$('td', row).eq(4).attr('title', $('td', row).eq(4).text());
$('td', row).eq(4).attr('data-export', $('td', row).eq(4).text());
- if ($('td', row).eq(4).text().length > 60) {
- $('td', row).eq(4).text($('td', row).eq(4).text().substring(0, 60));
+ if ($('td', row).eq(4).text().length > 55) {
+ $('td', row).eq(4).text($('td', row).eq(4).text().substring(0, 55));
$('td', row).eq(4).text($('td', row).eq(4).text() + '...')
}
$('td', row).eq(5).attr('data-export', $('td', row).eq(5).text());
@@ -209,13 +214,13 @@
"columns": [
{ "type": "natural", "width": "2%" },
{ "type": "natural", "width": "5%" },
- { "type": "natural", "width": "12%" },
- { "type": "natural", "width": "12%" },
+ { "type": "natural", "width": "10%" },
+ { "type": "natural", "width": "8%" },
{ "type": "natural" },
- { "type": "natural", "width": "11%" },
+ { "type": "natural", "width": "12%" },
{ "type": "natural", "width": "4%" },
{ "type": "natural", "width": "5%" },
- { "type": "natural", "width": "11%" },
+ { "type": "natural", "width": "12%" },
{ "type": "natural", "width": "5%" }
],
"columnDefs": [ {
@@ -235,10 +240,6 @@
"autoWidth": false,
"deferRender": true,
"bSortClasses": false,
- "scrollX": true,
- "scrollY": "600px",
- "scrollCollapse": false,
- "scroller": true,
"paging": false,
"orderClasses": true
} );
@@ -254,7 +255,8 @@
$('.trait_checkbox:checkbox').on("change", change_buttons);
},
"createdRow": function ( row, data, index ) {
- $('td', row).eq(0).attr('style', 'padding-left: 8px; padding-right: 0px; padding-top: 4px; align: center;');
+ $('td', row).eq(0).attr('style', 'padding: 0px;');
+ $('td', row).eq(0).attr('align', 'center');
$('td', row).eq(1).attr('align', 'right');
$('td', row).eq(1).attr('data-export', index+1);
$('td', row).eq(2).attr('data-export', $('td', row).eq(2).text());
@@ -308,9 +310,6 @@
"autoWidth": false,
"deferRender": true,
"bSortClasses": false,
- "scrollY": "600px",
- "scrollCollapse": false,
- "scroller": false,
"paging": false,
"orderClasses": true
} );
@@ -325,7 +324,8 @@
$('.trait_checkbox:checkbox').on("change", change_buttons);
},
"createdRow": function ( row, data, index ) {
- $('td', row).eq(0).attr('style', 'padding-left: 8px; padding-right: 0px; padding-top: 4px; align: center;');
+ $('td', row).eq(0).attr('style', 'padding: 0px;');
+ $('td', row).eq(0).attr('align', 'center');
$('td', row).eq(1).attr('align', 'right');
$('td', row).eq(1).attr('data-export', index+1);
$('td', row).eq(2).attr('data-export', $('td', row).eq(2).text());
@@ -333,10 +333,10 @@
},
"data": json_trait_list,
"columns": [
- { "type": "natural", "width": "5%" },
- { "type": "natural", "width": "12%" },
{ "type": "natural" },
- { "type": "natural", "width": "30%"}
+ { "type": "natural" },
+ { "type": "natural" },
+ { "type": "natural" }
],
"columnDefs": [ {
"targets": 0,
@@ -355,9 +355,6 @@
"autoWidth": false,
"deferRender": true,
"bSortClasses": false,
- "scrollY": "600px",
- "scrollCollapse": true,
- "scroller": true,
"paging": false,
"orderClasses": true
} );
diff --git a/wqflask/wqflask/templates/show_trait_edit_data.html b/wqflask/wqflask/templates/show_trait_edit_data.html
index ab134663..090602f4 100644
--- a/wqflask/wqflask/templates/show_trait_edit_data.html
+++ b/wqflask/wqflask/templates/show_trait_edit_data.html
@@ -110,7 +110,7 @@
<tbody>
{% for sample in sample_type.sample_list %}
<tr class="{{ sample.class_outlier }} value_se" id="{% if outer_loop.index == 1 %}Primary_{{ sample.this_id }}{% else %}Other_{{ sample.this_id }}{% endif %}">
- <td align="center" style="padding-left: 0px; padding-right: 0px;" class="column_name-"><input type="checkbox" name="selectCheck" class="checkbox edit_sample_checkbox" value="{{ sample.name }}" checked="checked">
+ <td align="center" style="padding-left: 0px; padding-right: 0px; padding-top: 2px; padding-bottom: 0px;" class="column_name-"><input type="checkbox" name="selectCheck" class="checkbox edit_sample_checkbox" style="min-height: 20px;" value="{{ sample.name }}" checked="checked">
</td>
<td class="column_name-Index" align="right">{{ loop.index }}</td>
<td class="column_name-Sample">
@@ -120,7 +120,7 @@
</td>
{# Todo: Add IDs #}
- <td class="column_name-Value" align="right">
+ <td class="column_name-Value" align="right" style="padding-top: 2px; padding-bottom: 0px;">
<input type="text" data-value="{{ sample.display_value }}" data-qnorm="{{ qnorm_vals[outer_loop.index - 1][loop.index - 1] }}" name="{{ 'value:' + sample.name }}"
style="text-align:right;"
class="trait_value_input edit_sample_value"
@@ -135,7 +135,7 @@
</td>
{# Todo: Add IDs #}
- <td class="column_name-SE" align="right">
+ <td class="column_name-SE" align="right" style="padding-top: 2px; padding-bottom: 0px;">
<input type="text" data-value="{{ sample.display_variance }}" data-qnorm="x" name="{{ 'variance:' + sample.name}}"
style="text-align:right;"
class="trait_value_input edit_sample_se"
diff --git a/wqflask/wqflask/templates/show_trait_transform_and_filter.html b/wqflask/wqflask/templates/show_trait_transform_and_filter.html
index 5d14a30e..fdf34c27 100644
--- a/wqflask/wqflask/templates/show_trait_transform_and_filter.html
+++ b/wqflask/wqflask/templates/show_trait_transform_and_filter.html
@@ -8,7 +8,7 @@
<div id="blockMenuSpan" class="input-append" style="margin-bottom: 10px;">
<label for="remove_samples_field">Block samples by index:</label>
- <input type="text" id="remove_samples_field">
+ <input type="text" id="remove_samples_field" placeholder="Example: 3, 5-10, 12">
<select id="block_group" size="1">
<option value="primary">
{{ sample_group_types['samples_primary'] }}
diff --git a/wqflask/wqflask/marker_regression/run_mapping.py b/wqflask/wqflask/marker_regression/run_mapping.py
index aee3cc2a..3057e340 100644
--- a/wqflask/wqflask/marker_regression/run_mapping.py
+++ b/wqflask/wqflask/marker_regression/run_mapping.py
@@ -652,9 +652,9 @@ def trim_markers_for_table(markers):
else:
sorted_markers = sorted(markers, key=lambda k: k['lrs_value'], reverse=True)
- #ZS: So we end up with a list of just 200 markers
- if len(sorted_markers) >= 200:
- trimmed_sorted_markers = sorted_markers[:200]
+ #ZS: So we end up with a list of just 2000 markers
+ if len(sorted_markers) >= 2000:
+ trimmed_sorted_markers = sorted_markers[:2000]
return trimmed_sorted_markers
else:
return sorted_markers \ No newline at end of file